@@ -916,7 +916,7 @@ class Askdata(SignUp):
             "data": df.to_dict(orient="record"),
             "schema": schema,
             "locale": locale,
-            "defaultImportValues": skip_import_values
+            "defaultImportValues": (not skip_import_values)
         }
 
         if (replace):
